@@ -39,8 +39,8 @@ getResponse = function(f) {
 
 
 getREterms = function(f) {
-  .loadOptionalPackage('lme4')
-  terms = lme4::findbars(f)
+  .loadOptionalPackage('reformulas')
+  terms = reformulas::findbars(f)
 }
 
 
