@@ -3,7 +3,7 @@
 #' @name interface-kml
 #' @rdname interface-kml
 #' @title kml interface
-#' @seealso [lcMethodKML] \link[kml]{kml}
+#' @seealso [lcMethodKML]
 #' @keywords internal
 NULL
 
@@ -15,13 +15,13 @@ setClass('lcMethodKML', contains = 'lcMatrixMethod')
 #' @param time The name of the time variable.
 #' @param id The name of the trajectory identifier variable.
 #' @param nClusters The number of clusters to estimate.
-#' @param ... Arguments passed to [kml::parALGO] and [kml::kml].
+#' @param ... Arguments passed to `parALGO` and `kml` from kml package.
 #'
 #' The following external arguments are ignored: object, nbClusters, parAlgo, toPlot, saveFreq
 #' @examples
 #' data(latrendData)
 #'
-#' if (require("kml")) {
+#' if (FALSE) {
 #'   method <- lcMethodKML("Y", id = "Id", time = "Time", nClusters = 3)
 #'   model <- latrend(method, latrendData)
 #' }
@@ -35,6 +35,7 @@ lcMethodKML = function(
   nClusters = 2,
   ...
 ) {
+  .loadOptionalPackage('kml')
   mc = match.call.all()
   mc$Class = 'lcMethodKML'
   do.call(new, as.list(mc))
@@ -44,8 +45,8 @@ lcMethodKML = function(
 setMethod('getArgumentDefaults', 'lcMethodKML', function(object) {
   c(
     formals(lcMethodKML),
-    formals(kml::kml),
-    formals(kml::parALGO),
+    formals(.getKmlFunction('kml')),
+    formals(.getKmlFunction('parALGO')),
     callNextMethod()
   )
 })
@@ -78,7 +79,7 @@ setMethod('preFit', 'lcMethodKML', function(method, data, envir, verbose, ...) {
 
   # workaround for KmL only using the fast version when meanNA() of the longitudinalData package is specified
   if (identical(method$centerMethod, meanNA)) {
-    method = update(method, centerMethod = longitudinalData::meanNA)
+    method = update(method, centerMethod = utils::getFromNamespace('meanNA', 'longitudinalData'))
   }
 
   valueColumn = responseVariable(method)
@@ -91,10 +92,12 @@ setMethod('preFit', 'lcMethodKML', function(method, data, envir, verbose, ...) {
     scale = FALSE
   )
 
-  parArgs = modifyList(parRefArgs, as.list(method, args = kml::parALGO), keep.null = TRUE)
-  e$par = do.call(kml::parALGO, parArgs)
+  parALGO = .getKmlFunction('parALGO')
+  parArgs = modifyList(parRefArgs, as.list(method, args = parALGO), keep.null = TRUE)
+  e$par = do.call(parALGO, parArgs)
 
-  e$cld = kml::clusterLongData(
+  clusterLongData = .getKmlFunction('clusterLongData')
+  e$cld = clusterLongData(
     traj = e$dataMat,
     idAll = rownames(e$dataMat),
     time = sort(unique(data[[timeVariable(method)]]))
@@ -118,7 +121,8 @@ setMethod('fit', 'lcMethodKML', function(method, data, envir, verbose, ...) {
 
   cat(verbose, 'Running kml()...', level = verboseLevels$finest)
   # note that slowKML throws an error for nbClusters=1
-  kml::kml(
+  kml = .getKmlFunction('kml')
+  kml(
     cld,
     nbClusters = method$nClusters,
     nbRedrawing = method$nbRedrawing,
@@ -143,3 +147,9 @@ setMethod('fit', 'lcMethodKML', function(method, data, envir, verbose, ...) {
     clusterNames = make.clusterNames(method$nClusters)
   )
 })
+
+.getKmlFunction = function(name) {
+  .loadOptionalPackage('kml')
+
+  utils::getFromNamespace(name, 'kml')
+}
\ No newline at end of file
