@@ -1,13 +1,12 @@
-context('akmedoids')
 skip_if_not_installed('akmedoids', minimum_version = '1.3.0')
 rngReset()
 # akmedoids requires at least 3 clusters, so most tests cannot be applied
 tests = c('method', 'cluster-three')
 
-library(akmedoids)
+.loadOptionalPackage('akmedoids')
 
 # Generate data ####
-data(traj, package = 'akmedoids')
+data(traj)
 capture.output({
   impTraj = data_imputation(traj, id_field = TRUE, method = 2, replace_with = 1, fill_zeros = FALSE)
 })
