@@ -352,15 +352,18 @@ test_that('as.list with function', {
   skip_if_not_installed('kml')
 
   method = lcMethodTestKML()
-  lis = as.list(method, args = kml::parALGO)
-  expect_length(setdiff(names(lis), formalArgs(kml::parALGO)), 0)
+  parALGO = .getKmlFunction('parALGO')
+  lis = as.list(method, args = parALGO)
+  expect_length(setdiff(names(lis), formalArgs(parALGO)), 0)
 })
 
 test_that('as.list with two functions', {
   skip_if_not_installed('kml')
 
   method = lcMethodTestKML()
-  funs = c(kml::parALGO, kml::kml)
+  parALGO = .getKmlFunction('parALGO')
+  kml = .getKmlFunction('kml')
+  funs = c(parALGO, kml)
   lis = as.list(method, args = funs)
   expect_length(setdiff(names(lis), union(formalArgs(funs[[1]]), formalArgs(funs[[2]]))), 0)
 })
